import {__decorate,__param,__metadata}from'tslib';import Axios from'axios';import*as _ from'lodash-es';import'bunyan';import {REGISTRY_ROUTES}from'../constants.js';import {parse,format}from'url';import {Connection}from'mongoose';import {injectable,inject}from'inversify';import {RegistryModelFunc}from'../documents/registry.js';import {config}from'../config/env-config.js';let RegistryManagement = class RegistryManagement {
  model;
  basicURL = config.HARBOR_BASE_URI;
  constructor(logger, db) {
    this.model = RegistryModelFunc(db);
  }
  routes = {
    [REGISTRY_ROUTES.CREATE]: () => `${this.basicURL}/api/v2.0/registries/`,
    [REGISTRY_ROUTES.UPDATE]: ({
      id
    }) => `${this.basicURL}/api/v2.0/registries/${id}`,
    [REGISTRY_ROUTES.REMOVE]: ({
      id
    }) => `${this.basicURL}/api/v2.0/registries/${id}`,
    [REGISTRY_ROUTES.REGISTRIES]: () => `${this.basicURL}/api/v2.0/registries/`
  };
  endpoint(route, input) {
    const fn = this.routes[route];
    return fn(input);
  }
  authHeader() {
    return {
      auth: {
        username: config.HARBOR_API_USER,
        password: config.HARBOR_API_PASSWORD
      }
    };
  }
  async createRegistry(payload) {
    const endpoint = this.endpoint(REGISTRY_ROUTES.CREATE);
    const data = {
      name: payload.name,
      url: payload.url,
      description: payload.description,
      type: payload.type,
      credentials: {
        access_key: payload.access_key,
        access_secret: payload.access_secret,
        type: 'basic'
      }
    };
    const header = this.authHeader();
    try {
      await Axios.post(endpoint, data, header);
      return true;
    } catch (e) {
      return false;
    }
  }
  async updateRegistry(id, payload) {
    // return true;
    const endpoint = this.endpoint(REGISTRY_ROUTES.UPDATE, {
      id
    });
    const data = {
      name: payload.name,
      url: payload.url,
      description: payload.description,
      type: payload.type,
      credentials: {
        access_key: payload.access_key,
        access_secret: payload.access_secret,
        type: 'basic'
      }
    };
    const header = this.authHeader();
    try {
      await Axios.put(endpoint, data, header);
      return true;
    } catch (e) {
      return false;
    }
  }
  async removeRegistry(id) {
    const endpoint = this.endpoint(REGISTRY_ROUTES.REMOVE, {
      id
    });
    const header = this.authHeader();
    try {
      await Axios.delete(endpoint, header);
      return true;
    } catch (e) {
      return false;
    }
  }
  async allDockerRegistries() {
    // return [{ name: 'asdf' }];
    const endpoint = this.endpoint(REGISTRY_ROUTES.REGISTRIES, {});
    const header = this.authHeader();
    try {
      const response = await Axios.get(endpoint, header).then(({
        data
      }) => data).then(res => res.data || res);
      const dockerRegistries = _.filter(response, registry => {
        return registry.type === 'docker-hub' || registry.type === 'docker-registry';
      });
      return dockerRegistries;
    } catch (e) {
      return {};
    }
  }
  async create(payload) {
    return this.model.create(payload);
  }
  async update(id, payload) {
    await this.model.update(id, payload);
    return this.find(id);
  }
  async list(owner_id) {
    return this.model.find({
      $or: [{
        owner_id
      }, {
        is_public: true
      }]
    }).exec();
  }
  async find(_id) {
    return this.model.findById(_id).exec();
  }
  async remove(_id) {
    return this.model.remove({
      _id
    }).then(() => true);
  }
  async test({
    url,
    credentials
  }) {
    const obj = parse(url);
    if (credentials.username) {
      Object.assign(obj, _.pick(credentials, ['username', 'password']));
    }
    let endpoint = format(obj);
    try {
      return Axios.get(endpoint, {
        headers: {
          [credentials.header]: credentials.token
        }
      }).then(() => true).catch(() => false);
    } catch (e) {
      return false;
    }
  }
};
RegistryManagement = __decorate([injectable(), __param(0, inject('Logger')), __param(1, inject('MongoDBConnection')), __metadata("design:paramtypes", [Object, Connection])], RegistryManagement);export{RegistryManagement};//# sourceMappingURL=RegistryManagement.js.map
